@@ -18,6 +18,7 @@ package v1alpha1
 
 import (
 	"context"
+	"fmt"
 
 	"knative.dev/pkg/apis"
 )
@@ -28,6 +29,11 @@ func (td *TektonDashboard) Validate(ctx context.Context) (errs *apis.FieldError)
 		return nil
 	}
 
+	if td.GetName() != DashboardResourceName {
+		errMsg := fmt.Sprintf("metadata.name,  Only one instance of TektonDashboard is allowed by name, %s", DashboardResourceName)
+		errs = errs.Also(apis.ErrInvalidValue(td.GetName(), errMsg))
+	}
+
 	if td.Spec.TargetNamespace == "" {
 		errs = errs.Also(apis.ErrMissingField("spec.targetNamespace"))
 	}
