@@ -19,15 +19,13 @@ package tektondashboard
 import (
 	"context"
 	"fmt"
-	"time"
-
 	mf "github.com/manifestival/manifestival"
-
 	"github.com/tektoncd/operator/pkg/apis/operator/v1alpha1"
 	clientset "github.com/tektoncd/operator/pkg/client/clientset/versioned"
 	pipelineinformer "github.com/tektoncd/operator/pkg/client/informers/externalversions/operator/v1alpha1"
 	tektondashboardreconciler "github.com/tektoncd/operator/pkg/client/injection/reconciler/operator/v1alpha1/tektondashboard"
 	"github.com/tektoncd/operator/pkg/reconciler/common"
+	"github.com/tektoncd/operator/pkg/reconciler/kubernetes/tektoninstallerset"
 	"github.com/tektoncd/operator/pkg/reconciler/shared/hash"
 	corev1 "k8s.io/api/core/v1"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
@@ -51,8 +49,6 @@ type Reconciler struct {
 	// a particular version with readonly value as false
 	fullaccessManifest mf.Manifest
 	// Platform-specific behavior to affect the transform
-	// enqueueAfter enqueues a obj after a duration
-	enqueueAfter     func(obj interface{}, after time.Duration)
 	extension        common.Extension
 	pipelineInformer pipelineinformer.TektonPipelineInformer
 	operatorVersion  string
@@ -63,7 +59,14 @@ type Reconciler struct {
 var _ tektondashboardreconciler.Interface = (*Reconciler)(nil)
 var _ tektondashboardreconciler.Finalizer = (*Reconciler)(nil)
 
-var watchedResourceName = "dashboard"
+var (
+	ls = metav1.LabelSelector{
+		MatchLabels: map[string]string{
+			v1alpha1.CreatedByKey:     createdByValue,
+			v1alpha1.InstallerSetType: v1alpha1.DashboardResourceName,
+		},
+	}
+)
 
 const createdByValue = "TektonDashboard"
 
@@ -87,11 +90,6 @@ func (r *Reconciler) FinalizeKind(ctx context.Context, original *v1alpha1.Tekton
 		return err
 	}
 
-	ls := metav1.LabelSelector{
-		MatchLabels: map[string]string{
-			v1alpha1.CreatedByKey: createdByValue,
-		},
-	}
 	labelSelector, err := common.LabelSelector(ls)
 	if err != nil {
 		return err
@@ -120,9 +118,9 @@ func (r *Reconciler) ReconcileKind(ctx context.Context, td *v1alpha1.TektonDashb
 
 	logger.Infow("Reconciling TektonDashboards", "status", td.Status)
 
-	if td.GetName() != watchedResourceName {
+	if td.GetName() != v1alpha1.DashboardResourceName {
 		msg := fmt.Sprintf("Resource ignored, Expected Name: %s, Got Name: %s",
-			watchedResourceName,
+			v1alpha1.DashboardResourceName,
 			td.GetName(),
 		)
 		logger.Error(msg)
@@ -135,8 +133,7 @@ func (r *Reconciler) ReconcileKind(ctx context.Context, td *v1alpha1.TektonDashb
 		if err.Error() == common.PipelineNotReady {
 			td.Status.MarkDependencyInstalling("tekton-pipelines is still installing")
 			// wait for pipeline status to change
-			r.enqueueAfter(td, 10*time.Second)
-			return nil
+			return v1alpha1.REQUEUE_EVENT_AFTER
 
 		}
 		// (tektonpipeline.opeator.tekton.dev instance not available yet)
@@ -153,11 +150,16 @@ func (r *Reconciler) ReconcileKind(ctx context.Context, td *v1alpha1.TektonDashb
 	// Mark PreReconcile Complete
 	td.Status.MarkPreReconcilerComplete()
 
-	// Check if an tekton installer set already exists, if not then create
-	existingInstallerSet := td.Status.GetTektonInstallerSet()
+	// Check if an tektoninstallerset already exists, if not then create
+	labelSelector, err := common.LabelSelector(ls)
+	if err != nil {
+		return err
+	}
+	existingInstallerSet, err := tektoninstallerset.CurrentInstallerSetName(ctx, r.operatorClientSet, labelSelector)
+	if err != nil {
+		return err
+	}
 	if existingInstallerSet == "" {
-		td.Status.MarkInstallerSetNotAvailable("Dashboard Installer Set Not Available")
-
 		createdIs, err := r.createInstallerSet(ctx, td)
 		if err != nil {
 			return err
@@ -182,7 +184,7 @@ func (r *Reconciler) ReconcileKind(ctx context.Context, td *v1alpha1.TektonDashb
 	}
 
 	installerSetTargetNamespace := installedTIS.Annotations[v1alpha1.TargetNamespaceKey]
-	installerSetReleaseVersion := installedTIS.Annotations[v1alpha1.ReleaseVersionKey]
+	installerSetReleaseVersion := installedTIS.Labels[v1alpha1.ReleaseVersionKey]
 
 	// Check if TargetNamespace of existing TektonInstallerSet is same as expected
 	// Check if Release Version in TektonInstallerSet is same as expected
@@ -203,8 +205,7 @@ func (r *Reconciler) ReconcileKind(ctx context.Context, td *v1alpha1.TektonDashb
 			Get(ctx, existingInstallerSet, metav1.GetOptions{})
 		if err == nil {
 			td.Status.MarkNotReady("Waiting for previous installer set to get deleted")
-			r.enqueueAfter(td, 10*time.Second)
-			return nil
+			return v1alpha1.REQUEUE_EVENT_AFTER
 		}
 		if !apierrors.IsNotFound(err) {
 			logger.Error("failed to get InstallerSet: %s", err)
@@ -256,8 +257,7 @@ func (r *Reconciler) ReconcileKind(ctx context.Context, td *v1alpha1.TektonDashb
 
 			// after updating installer set enqueue after a duration
 			// to allow changes to get deployed
-			r.enqueueAfter(td, 20*time.Second)
-			return nil
+			return v1alpha1.REQUEUE_EVENT_AFTER
 		}
 	}
 
@@ -267,18 +267,15 @@ func (r *Reconciler) ReconcileKind(ctx context.Context, td *v1alpha1.TektonDashb
 	ready := installedTIS.Status.GetCondition(apis.ConditionReady)
 	if ready == nil {
 		td.Status.MarkInstallerSetNotReady("Waiting for installation")
-		r.enqueueAfter(td, 10*time.Second)
-		return nil
+		return v1alpha1.REQUEUE_EVENT_AFTER
 	}
 
 	if ready.Status == corev1.ConditionUnknown {
 		td.Status.MarkInstallerSetNotReady("Waiting for installation")
-		r.enqueueAfter(td, 10*time.Second)
-		return nil
+		return v1alpha1.REQUEUE_EVENT_AFTER
 	} else if ready.Status == corev1.ConditionFalse {
 		td.Status.MarkInstallerSetNotReady(ready.Message)
-		r.enqueueAfter(td, 10*time.Second)
-		return nil
+		return v1alpha1.REQUEUE_EVENT_AFTER
 	}
 
 	// Mark InstallerSet Ready
@@ -336,7 +333,7 @@ func (r *Reconciler) createInstallerSet(ctx context.Context, td *v1alpha1.Tekton
 	}
 
 	// create installer set
-	tis := makeInstallerSet(td, manifest, specHash, r.operatorVersion)
+	tis := r.makeInstallerSet(td, manifest, specHash)
 	createdIs, err := r.operatorClientSet.OperatorV1alpha1().TektonInstallerSets().
 		Create(ctx, tis, metav1.CreateOptions{})
 	if err != nil {
@@ -345,16 +342,17 @@ func (r *Reconciler) createInstallerSet(ctx context.Context, td *v1alpha1.Tekton
 	return createdIs, nil
 }
 
-func makeInstallerSet(td *v1alpha1.TektonDashboard, manifest mf.Manifest, tdSpecHash, releaseVersion string) *v1alpha1.TektonInstallerSet {
+func (r *Reconciler) makeInstallerSet(td *v1alpha1.TektonDashboard, manifest mf.Manifest, tdSpecHash string) *v1alpha1.TektonInstallerSet {
 	ownerRef := *metav1.NewControllerRef(td, td.GetGroupVersionKind())
 	return &v1alpha1.TektonInstallerSet{
 		ObjectMeta: metav1.ObjectMeta{
 			GenerateName: fmt.Sprintf("%s-", v1alpha1.DashboardResourceName),
 			Labels: map[string]string{
-				v1alpha1.CreatedByKey: createdByValue,
+				v1alpha1.CreatedByKey:      createdByValue,
+				v1alpha1.InstallerSetType:  v1alpha1.DashboardResourceName,
+				v1alpha1.ReleaseVersionKey: r.operatorVersion,
 			},
 			Annotations: map[string]string{
-				v1alpha1.ReleaseVersionKey:  releaseVersion,
 				v1alpha1.TargetNamespaceKey: td.Spec.TargetNamespace,
 				v1alpha1.LastAppliedHashKey: tdSpecHash,
 			},
