@@ -29,11 +29,13 @@ source $(dirname $0)/config.sh
 function install_operator_resources() {
 
   echo :Payload Targets:
-  echo Pipelines: ${PIPELINES}
-  echo Triggers: ${TRIGGERS}
+  echo Pipelines: ${TEKTON_PIPELINE_VERSION}
+  echo Triggers: ${TEKTON_TRIGGERS_VERSION}
+  echo Chains: ${TEKTON_CHAINS_VERSION}
+  echo Hub: ${TEKTON_HUB_VERSION}
   if [[ ${TARGET} != "openshift" ]]; then
-    echo Results: ${RESULTS}
-    echo Dashboard: ${DASHBOARD}
+    echo Results: ${TEKTON_RESULTS_VERSION}
+    echo Dashboard: ${TEKTON_DASHBOARD_VERSION}
   fi
   echo '------------------------------'
 
@@ -47,9 +49,21 @@ function install_operator_resources() {
   # Wait for pods to be running in the namespaces we are deploying to
   # TODO: parameterize namespace, operator can run in a namespace different from the namespace where tektonpipelines is installed
   wait_until_pods_running ${OPERATOR_NAMESPACE} || fail_test "Tekton Operator controller did not come up"
+}
 
-  # Make sure that everything is cleaned up in the current namespace.
-  for res in tektonpipelines tektontriggers tektondashboards; do
-    kubectl delete --ignore-not-found=true ${res}.operator.tekton.dev --all
+function tektonconfig_ready_wait() {
+  echo "Wait for controller to start and create TektonConfig"
+  TEKTONCONFIG_READY=False
+  until [[ "${TEKTONCONFIG_READY}" = "True" ]]; do
+    echo waiting for TektonConfig config Ready status
+    sleep 5
+    kubectl get TektonConfig config > /dev/null 2>&1
+    if [[ $? -ne 0 ]]; then
+      echo TektonConfig config not yet created
+      continue
+    fi
+    TEKTONCONFIG_READY=$(kubectl get tektonconfig config -o jsonpath='{.status.conditions[?(@.type=="Ready")].status}')
+
   done
+  echo "TektonConfig config Ready: True"
 }
