@@ -139,3 +139,19 @@ func (c *Clients) TektonResult() operatorv1alpha1.TektonResultInterface {
 func (c *Clients) TektonResultAll() operatorv1alpha1.TektonResultInterface {
 	return c.Operator.TektonResults()
 }
+
+func (c *Clients) TektonChains() operatorv1alpha1.TektonChainInterface {
+	return c.Operator.TektonChains()
+}
+
+func (c *Clients) TektonChainsAll() operatorv1alpha1.TektonChainInterface {
+	return c.Operator.TektonChains()
+}
+
+func (c *Clients) TektonInstallerSet() operatorv1alpha1.TektonInstallerSetInterface {
+	return c.Operator.TektonInstallerSets()
+}
+
+func (c *Clients) TektonInstallerSetAll() operatorv1alpha1.TektonInstallerSetInterface {
+	return c.Operator.TektonInstallerSets()
+}
